__version__ = "0.0.1"

# base
from .base.decreasing_progress_schedule import DecreasingProgressSchedule
from .base.increasing_progress_schedule import IncreasingProgressSchedule
from .base.schedule_base import ScheduleBase
#
from .constant import Constant
from .cosine_decreasing import CosineDecreasing
from .cosine_increasing import CosineIncreasing
from .linear_decreasing import LinearDecreasing
from .linear_increasing import LinearIncreasing
